Crate apply_license

Crate apply_license 

Structs

License
An open-source license.

Functions

parse_author_names
Parses author names from a list of author names, which might include git-style author names such as John Doe <jd@example.com>.
parse_spdx
Parse a list of license identifiers from an SPDX license expression.
render_license_text
Given a list of authors and SPDX license identifiers, returns a map from file name to contents.