Structs
- License
- An open-source license.
Functions
- parse_
author_ names - Parses author names from a list of author names, which might include git-style author names
such as
John Doe <jd@example.com>. - parse_
spdx - Parse a list of license identifiers from an SPDX license expression.
- render_
license_ text - Given a list of authors and SPDX license identifiers, returns a map from file name to contents.